LaneType

Enum LaneType 

pub enum LaneType {
Show 25 variants Unknown, Driving, Turn, Hov, Bus, Taxi, Emergency, Shoulder, Biking, Walking, Parking, Stop, Border, Curb, Median, Restricted, Construction, Rail, Entry, Exit, OnRamp, OffRamp, ConnectingRamp, SlipLane, Virtual,
}
Lane classification options.

LaneType defines the intended use of a lane.

Variants



Unknown

Default state.



Driving

Standard driving lane.



Turn

Turn available.



Hov

High Occupancy Vehicle lane (+2 passengers).



Bus

Bus only.



Taxi

Taxi only.



Emergency

Emergency vehicles only (fire, ambulance, police).



Shoulder

Soft border at the edge of the road.



Biking

Reserved for cyclists.



Walking

Sidewalks / Crosswalks.



Parking

Lane with parking spaces.



Stop

Hard shoulder / Emergency stop.



Border

Hard border at the edge of the road.



Curb

Curb stones.



Median

Sits between driving lanes that lead in opposite directions.



Restricted

Generic restricted (use if HOV/Bus/Emergency don’t fit).



Construction

Road works.



Rail

Trains/Trams.



Entry

Merge into main road.



Exit

Exit from the main road.



OnRamp

Ramp leading to a motorway.



OffRamp

Ramp leading away from a motorway.



ConnectingRamp



SlipLane

Change roads without driving into the main intersection.



Virtual

Intersection crossings with no physical markings.